==> nextcloud-19.0.8.tgz: nextcloud/apps/files_sharing/l10n/zh_TW.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "與您分享",
    "Nothing shared with you yet" : "目前沒有任何與您分享的內容",
    "Files and folders others share with you will show up here" : "與您分享的檔案與資料夾將會顯示在這裡",
    "Shared with others" : "與其他人分享",
    "Nothing shared yet" : "目前沒有分享內容",
    "Files and folders you share will show up here" : "您分享的檔案與資料夾將會顯示在這裡",
    "Shared by link" : "由連結分享",
    "No shared links" : "沒有已分享的連結",
    "Files and folders you share by link will show up here" : "您分享的檔案與資料夾連結將會顯示在這裡",
    "Deleted shares" : "移除分享",
    "No deleted shares" : "沒有移除的分享",
    "Shares you deleted will show up here" : "您刪除的分享會在此顯示",
    "Pending shares" : "等待分享",
    "No pending shares" : "沒有待處理的分享",
    "Shares you have received but not confirmed will show up here" : "您收到但尚未確認的分享將會在此顯示",
    "Shares" : "分享",
    "No shares" : "無分享",
    "Shares will show up here" : "分享將會在此顯示",
    "Restore" : "回復",
    "Restore share" : "還原分享",
    "Something happened. Unable to restore the share." : "出了些狀況，無法還原分享。",
    "Accept share" : "接受分享",
    "Something happened. Unable to accept the share." : "好像有東西出錯了。無法接受分享。",
    "Reject share" : "拒絕分享",
    "Something happened. Unable to reject the share." : "好像有東西出錯了。無法拒絕分享。",
    "Waiting…" : "正在等待……",
    "error" : "錯誤",
    "finished" : "已結束",
    "This will stop your current uploads." : "這會終止目前任何的上傳。",
    "Move or copy" : "移動或複製",
    "Download" : "下載",
    "Delete" : "移除",
    "You can upload into this folder" : "你可以上傳內容到此資料夾",
    "Terms of service" : "服務條款",
    "No compatible server found at {remote}" : "沒有在 {remote} 找到相容的伺服器",
    "Invalid server URL" : "無效的伺服器 URL",
    "Failed to add the public link to your Nextcloud" : "無法將公開連結加入您的 Nextcloud",
    "No expiration date set" : "未指定到期日",
    "Shared by" : "分享自",
    "File shares" : "檔案分享",
    "Downloaded via public link" : "透過公用連結下載",
    "Downloaded by {email}" : "{email} 已下載",
    "{file} downloaded via public link" : "{file} 已透過公用連結下載",
    "{email} downloaded {file}" : "{email} 已下載 {file}",
    "Shared with group {group}" : "與群組 {group} 分享",
    "Removed share for group {group}" : "移除與群組 {group} 分享",
    "{actor} shared with group {group}" : "{actor} 分享給群組 {group}",
    "{actor} removed share for group {group}" : "{actor} 移除了與群組 {group} 的分享",
    "Share for group {group} expired" : "群組 {group} 的分享已過期",
    "You shared {file} with group {group}" : "你分享了 {file} 給群組 {group}",
    "You removed group {group} from {file}" : "你將群組 {group} 從 {file} 移除",
    "{actor} shared {file} with group {group}" : "{actor} 分享 {file} 給群組 {group}",
    "{actor} removed group {group} from {file}" : "{actor} 將群組 {group} 從 {file} 移除",
    "Share for file {file} with group {group} expired" : "與群組 {group} 分享的檔案 {file} 已過期",
    "Shared as public link" : "藉由公用連結分享",
    "Removed public link" : "刪除公開連結",
    "Public link expired" : "公開連結已過期",
    "{actor} shared as public link" : "{actor} 透過公開連結分享",
    "{actor} removed public link" : "{actor} 移除公開連結分享",
    "Public link of {actor} expired" : "{actor} 的公開連結過期了",
    "You shared {file} as public link" : "你藉由公用連結分享了 {file}",
    "You removed public link for {file}" : "您刪除了 {file} 的公開分享連結",
    "Public link expired for {file}" : "{file} 的公開連結已過期",
    "{actor} shared {file} as public link" : "{actor} 透過公開連結分享 {file}",
    "{actor} removed public link for {file}" : "{actor} 移除 {file} 的公開連結分享",
    "Public link of {actor} for {file} expired" : "{actor} 公開分享 {file} 的連結過期了",
    "{user} accepted the remote share" : "{user} 接受了遠端分享",
    "{user} declined the remote share" : "{user} 拒絕了遠端分享",
    "You received a new remote share {file} from {user}" : "您收到了一個遠端分享 {file} 來自於 {user}",
    "{user} accepted the remote share of {file}" : "{user} 接受了檔案 {file} 的遠端分享",
    "{user} declined the remote share of {file}" : "{user} 拒絕了檔案 {file} 的遠端分享",
    "{user} unshared {file} from you" : "{user} 取消與你分享檔案 {file}",
    "Shared with {user}" : "與 {user} 分享",
    "Removed share for {user}" : "移除對 {user} 的分享",
    "You removed yourself" : "您自己移除",
    "{actor} removed themselves" : "{actor} 已將自己移除",
    "{actor} shared with {user}" : "{actor} 分享給 {user}",
    "{actor} removed share for {user}" : "{actor} 移除了對 {user} 的分享",
    "Shared by {actor}" : "由 {actor} 分享",
    "{actor} removed share" : "{actor} 移除了分享",
    "Share for {user} expired" : "{user} 的分享已過期",
    "Share expired" : "分享已過期",
    "You shared {file} with {user}" : "你與 {user} 分享了 {file}",
    "You removed {user} from {file}" : "你將 {user} 從 {file} 移除",
    "You removed yourself from {file}" : "您已將自己從 {file} 移除",
    "{actor} removed themselves from {file}" : "{actor} 從 {file} 移除了自己",
    "{actor} shared {file} with {user}" : "{actor} 分享了 {file} 給 {user}",
    "{actor} removed {user} from {file}" : "{actor} 移除 {user} 從 {file}",
    "{actor} shared {file} with you" : "{actor} 與你分享了 {file}",
    "{actor} removed you from the share named {file}" : "{actor} 將您從名為 {file} 的分享中移除了",
    "Share for file {file} with {user} expired" : "與 {user} 分享的檔案 {file} 已過期",
    "Share for file {file} expired" : "檔案 {file} 的分享已過期",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "email或公開連結分享的檔案與資料夾已被 <strong>下載</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "檔案或目錄已被 <strong>其他伺服器</strong> 分享",
    "Files" : "檔案",
    "A file or folder has been <strong>shared</strong>" : "檔案或目錄已被 <strong>分享</strong>",
    "Shared link" : "已分享的連結",
    "Wrong share ID, share doesn't exist" : "錯誤的分享 ID ，分享不存在",
    "Could not delete share" : "無法刪除分享",
    "Please specify a file or folder path" : "請指定檔案或資料夾路徑",
    "Wrong path, file/folder doesn't exist" : "錯誤的路徑，該檔案或資料夾不存在",
    "Could not create share" : "無法建立分享",
    "invalid permissions" : "無效的權限",
    "Please specify a valid user" : "請選擇一個有效的使用者",
    "Group sharing is disabled by the administrator" : "群組分享已被管理員停用",
    "Please specify a valid group" : "請指定一個有效的群組",
    "Public link sharing is disabled by the administrator" : "公開連結分享已被管理員停用",
    "Public upload disabled by the administrator" : "公開上傳已被管理員停用",
    "Public upload is only possible for publicly shared folders" : "只有公開分享的資料夾可以接受公開上傳",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "因為未啟用 Nextcloud Talk，因此透過 Nextcloud Talk 傳送密碼分享 %s 失敗",
    "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "分享 %1$s 失敗，因為後端不允許來自 %2$s 類型的分享",
    "You cannot share to a Circle if the app is not enabled" : "當應用未被啟用，你無法分享到circle。",
    "Please specify a valid circle" : "請指定一個有效的circle",
    "Sharing %s failed because the back end does not support room shares" : "分享 %s 失敗，因為後端不支援聊天室分享",
    "Unknown share type" : "未知的分享類型",
    "Not a directory" : "這不是一個資料夾",
    "Could not lock node" : "無法鎖定節點",
    "Could not lock path" : "無法鎖定路徑",
    "Wrong or no update parameter given" : "更新參數不正確或未提供",
    "Can't change permissions for public share links" : "無法由公開分享的連結變更權限",
    "Sharing sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "因為未啟用 Nextcloud Talk，因此透過 Nextcloud Talk 傳送密碼分享失敗",
    "shared by %s" : "分享自 %s",
    "Download all files" : "下載所有檔案",
    "Direct link" : "直接連結",
    "Add to your Nextcloud" : "加入到您的 Nextcloud",
    "Share API is disabled" : "分享 API 已停用",
    "File sharing" : "檔案分享",
    "Share will expire tomorrow" : "分享將於明天到期",
    "One or more of your shares will expire tomorrow" : "您的一個或多個分享將於明天到期",
    "Your share of {node} will expire tomorrow" : "您 {node} 的分享將於明天到期",
    "You received {share} as a share by {user}" : "您收到 {user} 的分享 {share}",
    "Accept" : "接受",
    "Reject" : "拒絕",
    "Sharing" : "分享",
    "Allow editing" : "允許編輯",
    "Allow resharing" : "允許轉貼分享",
    "Expiration date enforced" : "已設定到期日",
    "Set expiration date" : "設定到期日",
    "Note to recipient" : "給接收者的訊息",
    "Unshare" : "撤回分享",
    "group" : "群組",
    "conversation" : "交談",
    "remote" : "遠端",
    "remote group" : "遠端群組",
    "guest" : "訪客",
    "Link copied" : "連結已複製",
    "Copy to clipboard" : "複製到剪貼簿",
    "Only works for users with access to this folder" : "只對可以存取此資料夾的使用者生效",
    "Password protection" : "密碼保護",
    "Enter a password" : "輸入密碼",
    "Cancel" : "取消",
    "Read only" : "唯讀",
    "Allow upload and editing" : "允許上傳及編輯",
    "File drop (upload only)" : "拖曳檔案(僅供上傳)",
    "Hide download" : "隱藏下載",
    "Password protect" : "密碼防護",
    "Add another link" : "加入另一個連結",
    "Share link" : "分享連結",
    "Resharing is not allowed" : "不允許重新分享",
    "Search globally" : "全域搜尋",
    "Shared" : "已分享",
    "Share" : "分享",
    "Shared with" : "分享給",
    "Shared with you and the group {group} by {owner}" : "由 {owner} 分享給您和 {group}群組",
    "Shared with you and {circle} by {owner}" : "{owner} 分享給您和 {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} 分享給您和 {conversation} 對話",
    "Shared with you in a conversation by {owner}" : "{owner} 在對話中分享給您",
    "Shared with you by {owner}" : "{owner} 已經和您分享",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Name" : "名稱",
    "Share time" : "分享時間",
    "Expiration date" : "到期日",
    "Sorry, this link doesn’t seem to work anymore." : "抱歉，此連結已經失效",
    "Reasons might be:" : "可能的原因：",
    "the item was removed" : "項目已經移除",
    "the link expired" : "連結過期",
    "sharing is disabled" : "分享功能已停用",
    "For more info, please ask the person who sent this link." : "請詢問告訴您此連結的人以瞭解更多",
    "Toggle grid view" : "切換網格檢視",
    "Download %s" : "下載 %s",
    "Upload files to %s" : "上傳檔案到 %s",
    "Note" : "筆記",
    "Select or drop files" : "選擇或拖曳檔案至此",
    "Uploaded files:" : "已上傳的檔案：",
    "Uploading files…" : "上傳檔案中…"
},
"nplurals=1; plural=0;");

==> nextcloud-19.0.9.tgz: nextcloud/apps/files_sharing/l10n/zh_TW.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "與您分享",
    "Nothing shared with you yet" : "目前沒有任何與您分享的內容",
    "Files and folders others share with you will show up here" : "與您分享的檔案與資料夾將會顯示在這裡",
    "Shared with others" : "與其他人分享",
    "Nothing shared yet" : "目前沒有分享內容",
    "Files and folders you share will show up here" : "您分享的檔案與資料夾將會顯示在這裡",
    "Shared by link" : "由連結分享",
    "No shared links" : "沒有已分享的連結",
    "Files and folders you share by link will show up here" : "您分享的檔案與資料夾連結將會顯示在這裡",
    "Deleted shares" : "已刪除的分享",
    "No deleted shares" : "沒有已刪除的分享",
    "Shares you deleted will show up here" : "您刪除的分享會在此顯示",
    "Pending shares" : "擱置中的分享",
    "No pending shares" : "沒有擱置中的分享",
    "Shares you have received but not confirmed will show up here" : "您收到但尚未確認的分享將會在此顯示",
    "Shares" : "分享",
    "No shares" : "無分享",
    "Shares will show up here" : "分享將會在此顯示",
    "Restore" : "還原",
    "Restore share" : "還原分享",
    "Something happened. Unable to restore the share." : "好像有東西出錯了。無法還原分享。",
    "Accept share" : "接受分享",
    "Something happened. Unable to accept the share." : "好像有東西出錯了。無法接受分享。",
    "Reject share" : "拒絕分享",
    "Something happened. Unable to reject the share." : "好像有東西出錯了。無法拒絕分享。",
    "Waiting…" : "正在等待……",
    "error" : "錯誤",
    "finished" : "已結束",
    "This will stop your current uploads." : "這會停止您目前的上傳。",
    "Move or copy" : "移動或複製",
    "Download" : "下載",
    "Delete" : "刪除",
    "You can upload into this folder" : "您可以上傳到此資料夾",
    "Terms of service" : "服務條款",
    "No compatible server found at {remote}" : "在 {remote} 找不到相容的伺服器",
    "Invalid server URL" : "無效的伺服器 URL",
    "Failed to add the public link to your Nextcloud" : "無法將公開連結新增到您的 Nextcloud",
    "No expiration date set" : "未指定到期日",
    "Shared by" : "分享自",
    "File shares" : "檔案分享",
    "Downloaded via public link" : "透過公開連結下載",
    "Downloaded by {email}" : "{email} 已下載",
    "{file} downloaded via public link" : "{file} 已透過公開連結下載",
    "{email} downloaded {file}" : "{email} 已下載 {file}",
    "Shared with group {group}" : "與群組 {group} 分享",
    "Removed share for group {group}" : "移除與群組 {group} 分享",
    "{actor} shared with group {group}" : "{actor} 分享給群組 {group}",
    "{actor} removed share for group {group}" : "{actor} 移除了與群組 {group} 的分享",
    "Share for group {group} expired" : "群組 {group} 的分享已過期",
    "You shared {file} with group {group}" : "你分享了 {file} 給群組 {group}",
    "You removed group {group} from {file}" : "你將群組 {group} 從 {file} 移除",
    "{actor} shared {file} with group {group}" : "{actor} 分享 {file} 給群組 {group}",
    "{actor} removed group {group} from {file}" : "{actor} 將群組 {group} 從 {file} 移除",
    "Share for file {file} with group {group} expired" : "與群組 {group} 分享的檔案 {file} 已過期",
    "Shared as public link" : "以公開連結分享",
    "Removed public link" : "已移除公開連結",
    "Public link expired" : "公開連結已過期",
    "{actor} shared as public link" : "{actor} 透過公開連結分享",
    "{actor} removed public link" : "{actor} 移除公開連結分享",
    "Public link of {actor} expired" : "{actor} 的公開連結過期了",
    "You shared {file} as public link" : "您透過公開連結分享 {file}",
    "You removed public link for {file}" : "您移除了 {file} 的公開分享連結",
    "Public link expired for {file}" : "{file} 的公開連結已過期",
    "{actor} shared {file} as public link" : "{actor} 透過公開連結分享 {file}",
    "{actor} removed public link for {file}" : "{actor} 移除了 {file} 的公開連結分享",
    "Public link of {actor} for {file} expired" : "{actor} 公開分享 {file} 的連結過期了",
    "{user} accepted the remote share" : "{user} 接受了遠端分享",
    "{user} declined the remote share" : "{user} 拒絕了遠端分享",
    "You received a new remote share {file} from {user}" : "您收到了一個遠端分享 {file} 來自於 {user}",
    "{user} accepted the remote share of {file}" : "{user} 接受了檔案 {file} 的遠端分享",
    "{user} declined the remote share of {file}" : "{user} 拒絕了檔案 {file} 的遠端分享",
    "{user} unshared {file} from you" : "{user} 取消與你分享檔案 {file}",
    "Shared with {user}" : "與 {user} 分享",
    "Removed share for {user}" : "移除對 {user} 的分享",
    "You removed yourself" : "您移除了自己",
    "{actor} removed themselves" : "{actor} 已將自己移除",
    "{actor} shared with {user}" : "{actor} 分享給 {user}",
    "{actor} removed share for {user}" : "{actor} 移除了對 {user} 的分享",
    "Shared by {actor}" : "由 {actor} 分享",
    "{actor} removed share" : "{actor} 移除了分享",
    "Share for {user} expired" : "{user} 的分享已過期",
    "Share expired" : "分享已過期",
    "You shared {file} with {user}" : "你與 {user} 分享了 {file}",
    "You removed {user} from {file}" : "你將 {user} 從 {file} 移除",
    "You removed yourself from {file}" : "您已將自己從 {file} 移除",
    "{actor} removed themselves from {file}" : "{actor} 從 {file} 移除了自己",
    "{actor} shared {file} with {user}" : "{actor} 分享了 {file} 給 {user}",
    "{actor} removed {user} from {file}" : "{actor} 移除 {user} 從 {file}",
    "{actor} shared {file} with you" : "{actor} 與你分享了 {file}",
    "{actor} removed you from the share named {file}" : "{actor} 將您從名為 {file} 的分享中移除了",
    "Share for file {file} with {user} expired" : "與 {user} 分享的檔案 {file} 已過期",
    "Share for file {file} expired" : "檔案 {file} 的分享已過期",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "透過電子郵件或公開連結分享的檔案或資料夾<strong>已被下載</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "檔案或資料夾是從<strong>其他伺服器</strong>分享的",
    "Files" : "檔案",
    "A file or folder has been <strong>shared</strong>" : "檔案或資料夾已被<strong>分享</strong>",
    "Shared link" : "已分享的連結",
    "Wrong share ID, share doesn't exist" : "錯誤的分享 ID，分享不存在",
    "Could not delete share" : "無法刪除分享",
    "Please specify a file or folder path" : "請指定檔案或資料夾路徑",
    "Wrong path, file/folder doesn't exist" : "錯誤的路徑，該檔案或資料夾不存在",
    "Could not create share" : "無法建立分享",
    "invalid permissions" : "無效的權限",
    "Please specify a valid user" : "請指定有效使用者",
    "Group sharing is disabled by the administrator" : "群組分享已被管理員停用",
    "Please specify a valid group" : "請指定有效的群組",
    "Public link sharing is disabled by the administrator" : "公開連結分享已被管理員停用",
    "Public upload disabled by the administrator" : "公開上傳已被管理員停用",
    "Public upload is only possible for publicly shared folders" : "只有公開分享的資料夾可以接受公開上傳",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "因為未啟用 Nextcloud Talk，因此透過 Nextcloud Talk 傳送密碼分享 %s 失敗",
    "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "分享 %1$s 失敗，因為後端不允許來自 %2$s 類型的分享",
    "You cannot share to a Circle if the app is not enabled" : "因為應用程式未啟用，所以您無法分享至小圈圈",
    "Please specify a valid circle" : "請指定有效的小圈圈",
    "Sharing %s failed because the back end does not support room shares" : "分享 %s 失敗，因為後端不支援聊天室分享",
    "Unknown share type" : "未知的分享類型",
    "Not a directory" : "不是目錄",
    "Could not lock node" : "無法鎖定節點",
    "Could not lock path" : "無法鎖定路徑",
    "Wrong or no update parameter given" : "更新參數不正確或未提供",
    "Can't change permissions for public share links" : "無法變更公開分享連結的權限",
    "Sharing sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "因為未啟用 Nextcloud Talk，因此透過 Nextcloud Talk 傳送密碼分享失敗",
    "shared by %s" : "分享自 %s",
    "Download all files" : "下載所有檔案",
    "Direct link" : "直接連結",
    "Add to your Nextcloud" : "新增到您的 Nextcloud",
    "Share API is disabled" : "分享 API 已停用",
    "File sharing" : "檔案分享",
    "Share will expire tomorrow" : "分享將於明天到期",
    "One or more of your shares will expire tomorrow" : "您的一個或多個分享將於明天到期",
    "Your share of {node} will expire tomorrow" : "您 {node} 的分享將於明天到期",
    "You received {share} as a share by {user}" : "您收到 {user} 的分享 {share}",
    "You received {share} to group {group} as a share by {user}" : "您收到了來自 {user} 到 {group} 群組的 {share}",
    "Accept" : "接受",
    "Reject" : "拒絕",
    "This application enables users to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable users can then share files and folders with other users and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other users outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "此應用程式讓使用者可以在 Nextcloud 中分享檔案。若啟用，管理員可以選擇哪些群組可以分享檔案。應用程式使用者可以與其他在 Nextcloud 中的使用者與群組分享檔案與資料夾。此外，如果管理員啟用了分享連結的功能，則可以使用外部連結與 Nextcloud 之外的使用者分享檔案。管理員也可以啟用密碼、到期日以及啟用透過分享連結的伺服器到伺服器分享，並可從行動裝置分享。\n將此功能關閉會移除伺服器上、同步客戶端與行動應用程式所有的分享收件者，以及檔案與資料夾。更多資訊請見 Nextcloud 文件。",
    "Sharing" : "分享",
    "Accept user and group shares by default" : "預設接受使用者與群組分享",
    "Allow editing" : "允許編輯",
    "Allow creating" : "允許建立",
    "Allow deleting" : "允許刪除",
    "Allow resharing" : "允許轉分享",
    "Expiration date enforced" : "已設定到期日",
    "Set expiration date" : "設定到期日",
    "Enter a date" : "輸入日期",
    "Note to recipient" : "給收件者的訊息",
    "Unshare" : "取消分享",
    "group" : "群組",
    "conversation" : "交談",
    "remote" : "遠端",
    "remote group" : "遠端群組",
    "guest" : "訪客",
    "Shared with the group {user} by {owner}" : "由 {owner} 與群組 {user} 分享",
    "Shared with the conversation {user} by {owner}" : "由 {owner} 與對話 {user} 分享",
    "Shared with {user} by {owner}" : "由 {owner} 與 {user} 分享",
    "Added by {initiator}" : "由 {initiator} 新增",
    "Via “{folder}”" : "透過「{folder}」",
    "Internal link" : "內部連結",
    "Link copied" : "連結已複製",
    "Cannot copy, please copy the link manually" : "無法複製，請手動複製連結",
    "Copy to clipboard" : "複製到剪貼簿",
    "Only works for users with access to this folder" : "僅對可存取此資料夾的使用者有效",
    "Only works for users with access to this file" : "僅對可存取此檔案的使用者有效",
    "Please enter the following required information before creating the share" : "在建立分享前，請輸入以下的必要資訊",
    "Password protection (enforced)" : "密碼保護（強制）",
    "Password protection" : "密碼保護",
    "Enter a password" : "輸入密碼",
    "Expiration date (enforced)" : "到期日（強制）",
    "Create share" : "建立分享",
    "Cancel" : "取消",
    "Share label" : "分享標籤",
    "Read only" : "唯讀",
    "Allow upload and editing" : "允許上傳及編輯",
    "File drop (upload only)" : "檔案投放（僅上傳）",
    "Hide download" : "隱藏下載",
    "Password protect" : "密碼保護",
    "Video verification" : "視訊驗證",
    "Enter a note for the share recipient" : "輸入給分享收件者的訊息",
    "Add another link" : "新增其他連結",
    "Create a new share link" : "建立新分享連結",
    "{shareWith} by {initiator}" : "{shareWith} 由 {initiator}",
    "Shared via link by {initiator}" : "由 {initiator} 透過連結分享",
    "Share link" : "分享連結",
    "Resharing is not allowed" : "不允許重新分享",
    "Search globally" : "全域搜尋",
    "Shared" : "已分享",
    "Share" : "分享",
    "Shared with" : "分享給",
    "Shared with you and the group {group} by {owner}" : "由 {owner} 分享給您和 {group}群組",
    "Shared with you and {circle} by {owner}" : "{owner} 分享給您和 {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} 分享給您和 {conversation} 對話",
    "Shared with you in a conversation by {owner}" : "{owner} 在對話中分享給您",
    "Shared with you by {owner}" : "{owner} 已經和您分享",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Name" : "名稱",
    "Share time" : "分享時間",
    "Expiration date" : "到期日",
    "Sorry, this link doesn’t seem to work anymore." : "抱歉，此連結已經失效",
    "Reasons might be:" : "可能的原因：",
    "the item was removed" : "項目已經移除",
    "the link expired" : "連結過期",
    "sharing is disabled" : "分享功能已停用",
    "For more info, please ask the person who sent this link." : "請詢問告訴您此連結的人以瞭解更多",
    "Toggle grid view" : "切換網格檢視",
    "Download %s" : "下載 %s",
    "Upload files to %s" : "上傳檔案到 %s",
    "Note" : "筆記",
    "Select or drop files" : "選擇或拖曳檔案至此",
    "Uploaded files:" : "已上傳的檔案："
},
"nplurals=1; plural=0;");
